#
# spec file for package python-bcrypt
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2016, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-bcrypt
Version:        4.0.1
Release:        150400.5.6.1
Summary:        BSD type 2a and 2b password hashing
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/pyca/bcrypt/
Source0:        https://files.pythonhosted.org/packages/source/b/bcrypt/bcrypt-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 3.2.1}
BuildRequires:  %{python_module setuptools-rust}
BuildRequires:  %{python_module wheel}
# setuptools 40.8.0 is required by upstream only for a pip issue that doesn't
# affect us, so we relax the requirement to build in SLE/Leap 15.2 with 40.5.0
BuildRequires:  %{python_module setuptools >= 40.5.0}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-py-bcrypt = %{version}
Obsoletes:      python-py-bcrypt < %{version}

%python_subpackages

%description
This Python module supports creating (and verifying) password hashes
using the BSD-originating hashing methods known as "2a" and "2b".

%prep
%autosetup -p1 -a1 -n bcrypt-%{version}
mkdir .cargo
cp %{SOURCE2} .cargo/config
mv Cargo.lock src/_bcrypt

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}/%{$python_sitearch}

%check
%pytest_arch tests/

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/bcrypt
%{python_sitearch}/bcrypt-%{version}*-info

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Thu Nov  3 2022 daniel.garcia@suse.com
- Removed not needed C build dependencies
- Enable for all archs by default
* Wed Nov  2 2022 daniel.garcia@suse.com
- Update to 4.0.1:
  * We now build PyPy manylinux wheels.
  * Fixed a bug where passing an invalid salt to checkpw could result in a
    pyo3_runtime.PanicException. It now correctly raises a ValueError.
- 4.0.0:
  * bcrypt is now implemented in Rust. Users building from source will need to
    have a Rust compiler available. Nothing will change for users downloading
    wheels.
  * We no longer ship manylinux2010 wheels. Users should upgrade to the latest
    pip to ensure this doesn’t cause issues downloading wheels on their
    platform. We now ship manylinux_2_28 wheels for users on new enough
    platforms.
  * NUL bytes are now allowed in inputs.
* Wed Nov  2 2022 daniel.garcia@suse.com
- Remove not needed python-six dependency
* Wed May  4 2022 dmueller@suse.com
- update to 3.2.2:
  * Fixed packaging of ``py.typed`` files in wheels so that ``mypy`` works.
  * Added support for compilation on z/OS
  * The next release of ``bcrypt`` with be 4.0 and it will require Rust at
    compile time, for users building from source. There will be no additional
    requirement for users who are installing from wheels. Users on most
    platforms will be able to obtain a wheel by making sure they have an up to
    date ``pip``. The minimum supported Rust version will be 1.56.0.
* Thu Oct  8 2020 mcepl@suse.com
- Don't use deprecated 'python setup.py test', use pytest directly.
* Thu Aug 27 2020 adrian.glaubitz@suse.com
- Disable Python2 support to fix the build on older distributions
* Thu Aug 20 2020 mimi.vx@gmail.com
- update to 3.2.0
  * add type hints to top level functions
  * drop support for python 3.5 and older
  * drop legacy code
* Wed May 13 2020 alarrosa@suse.com
- Relax the setuptools dependency on 40.8.0 to 40.5.0 since that
  version is only required by upstream because of a pip issue
  (see https://github.com/pyca/bcrypt/commit/bc8a55e70e179a59fa89fb109353182f8f438e00).
  This way we can build in SLE 15 SP2 / Leap 15.2 .
* Sun Jul 28 2019 arun@gmx.de
- specfile:
  * update copyright year
  * changed setuptools min version
- update to version 3.1.7:
  * Set a setuptools lower bound for PEP517 wheel building.
  * We no longer distribute 32-bit manylinux1 wheels. Continuing to
    produce them was a maintenance burden.
- changes from version 3.1.6:
  * Added support for compilation on Haiku.
* Fri Mar  1 2019 tchvatal@suse.com
- Update to 3.1.5:
  * Added support for compilation on Haiku.
  * Added support for compilation on AIX.
  * Dropped Python 2.6 and 3.3 support.
  * Switched to using ``abi3`` wheels for Python 3. If you are not getting a
    wheel on a compatible platform please upgrade your ``pip`` version.
* Wed Aug 29 2018 tchvatal@suse.com
- Raise pytest requirement based on setup.py
* Wed Oct 25 2017 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.1.4:
  * Fixed compilation with mingw and on illumos.
* Sat May  6 2017 toddrme2178@gmail.com
- Don't provide python2-py-bcrypt, singlespec packages should use
  correct name.
* Sun Apr 30 2017 jengelh@inai.de
- Say which crypt methods this module actually supports.
* Sun Apr 30 2017 toddrme2178@gmail.com
- Update to version 3.1.3
  * Fixed a compilation issue on Solaris.
  * Added a warning when using too few rounds with kdf.
- Update to version 3.1.2
  * Fixed a compile issue affecting big endian platforms.
  * Fixed invalid escape sequence warnings on Python 3.6.
  * Fixed building in non-UTF8 environments on Python 2.
- Provides/Obsoletes "python-py-bcrypt" exactly.
- Change Summary/Description. Apparently "bcrypt is not "modern",
  not anymore."
* Thu Apr 27 2017 toddrme2178@gmail.com
- Fix license.
* Tue Apr 25 2017 toddrme2178@gmail.com
- Add Provides/Obsoletes py-bcrypt.
  This package is intended as a drop-in replacement for py-bcrypt
* Mon Apr 17 2017 axel.braun@gmx.de
- changes for singlespec
* Wed Oct  5 2016 dmueller@suse.com
- require the cffi version it was built against
* Thu Sep 29 2016 mardnh@gmx.de
- Update to version 3.1.1
  * Resolved a UserWarning when used with cffi 1.8.3.
* Thu Sep 15 2016 mardnh@gmx.de
- build with "-fno-strict-aliasing"
* Sun Sep 11 2016 mardnh@gmx.de
- initial package, version 3.1.0
